#ifndef spEngineDllH
#define spEngineDllH
// version 0.6
// structures mapping for DLL
#include "spGlobals.h"
struct Tpx_BrushCommonParams
   {
   // brush index (inside list)
   int ListIndex;  // internal use
   // brush tip
   int Size;
   int Capacity;
   int ColorVary;
   int SizeVary;
   int CapVary;
   int Step;
   // filters
   bool ChalkOn;
   bool InvertOn;
   int  InvertValue;
   bool  CloseOn;
   int CloseValue;
   bool BlurOn;
   int BlurValue;
   bool MedianOn;    // external - n/a
   int MedianValue;  // external - n/a
   // bump
   bool BumpOn;
   bool BumpSoft;
   float BumpScaleValue;
   int  BumpThresholdValue;
   int  BumpRoughnessValue;
   int BumpXoffsetValue;
   int BumpYoffsetValue;
   bool BumpInvertThreshold;
   // envelopes -> 0.4
   bool EnvelopeSizeOn;
   bool EnvelopeCapacityOn;
   bool EnvelopeSizeRepeat;
   bool EnvelopeCapacityRepeat;
   int  EnvelopeResolution;
   bool EnvelopeResolutionManual;
   // jitter
   bool JitterOn;
   bool JitterConnectedOn;
   int JitterRangeValue;
   int JitterLoopValue;
   // polygon
   bool PolyFillOver;
   bool PolyExcludeFilters;
   bool PolyExcludeBump;
   int  PolyColorIndex;
   bool PolyOverrideCapacityOn;
   int  PolyCapacityValue;
   bool PolyShrinkOn;
   int  PolyShrinkValue;
   bool PolyBlurOn;
   int  PolyBlurValue;
   // scratches
   int ScratchType;
   int ScratchThicknessValue;
   int ScratchNumberValue;
   // pal-grad stepper
   float PalGradStepper;
   bool  PalGradAuto;
   };
struct Tpx_RenderParams
   {
   bool ClearMask;
   bool HardMask;
   bool UpdateImage;
   bool AddUndo;
   int RenderingMode;
   bool DoShadow;
   bool DrawPolyInterior;
   bool DrawTipOnMouseDown;
   };
// Tpx_SelectionParams removed in 0.6
struct Tpx_DrawParams
   {
   int ArithMode;
   int SaveMode;
   int Shape;
   bool InvertSource;
   int BitShift;
   bool UpdateAlpha;
   int  StrokesNumber;      
   bool EraseMatchAll;
   int EraseMatchColorTolerance;
   // 0.4   
   bool DrawOnAlpha;  
   };
struct Tpx_ShadowParams
   {
   int MainMode;
   int Xoffset;
   int Yoffset;
   bool BlurOn;
   int BlurValue;
   int Capacity;
   };
struct Tpx_RenderData
   {
   Tpx_RenderParams RenderParams;
   Tpx_DrawParams DrawParams;
   Tpx_ShadowParams ShadowParams;
   };
// specific params
struct Tpx_BrushNeonSpecific
   {
   int FalloffIndex;
   int LinearValue;
   int TrigonometricValue;
   };
struct Tpx_BrushSolidSpecific
   {
   int Shape;
   int Thickness;
   bool Filled;      // 0.6
   float Angle;		   // 0.6
   bool RandomAngle; // 0.6   
   };
struct Tpx_BrushSpraySpecific
   {
   int Thickness;
   int IntVary;
   int Density;
   float Gravity;
   };
struct Tpx_BrushStarSpecific
   {
   int Thickness;
   int IntVary;
   int Density;
   };
struct Tpx_BrushMeshSpecific
   {
   int Thickness;
   int IntVary;
   int Density;
   };
struct Tpx_BrushHairSpecific
   {
   int Thickness;
   int IntVary;
   int Density;
   };
struct Tpx_BrushParallelSpecific
   {
   int Thickness;
   int IntVary;
   int Spacing;
   int Angle;
   };
struct Tpx_BrushCmlSpecific
   {
   int MinIntensity;
   int MaxIntensity;
   int SeedIntensity;
   int LatticeType;
   int CreationOps[9];
   int DestructionOps[9];
   float EpsilonGrow;
   float EpsilonDecay;
   int Iterations;
   int CreateProbability;
   int DecayProbability;
   int GrowProbability;
   bool Reborn;
   bool MatrixMes;
   bool DelayCreation;
   bool RandomSplat;
   bool SequentialScan;
   int  GrowFunc;
   int  DecayFunc;
   float EpsilonWeight;
   int CreationMutation;
   int DestructionMutation;
   };
struct Tpx_MouseData
   {
   int X_down;
   int Y_down;
   int X_up;
   int Y_up;
   int X_move_from;
   int Y_move_from;
   int X_move_to;
   int Y_move_to;
   int X_min;
   int Y_min;
   int X_max;
   int Y_max;
   int X_wrap_from;
   int Y_wrap_from;
   int X_wrap_to;
   int Y_wrap_to;
   bool MouseButtonDown;
   TShiftState Shift;
   };
struct Tpx_Geometry
   {
   bool SimplifyPolyline;
   int  SimplifyAlgorithm;    // Douglass-Poucker for now
   int  SimplifyDPTolerance;
   int  SimplifyMaxPts;		  // 0 by default
   int  PolygonModification;
   double RotationAngle;
   TPoint RotationOrigin;
   bool Filled;
   bool Border;
   bool PolyClosed;			// polygon
   };
//---------------------------------------------------------------------------
#define DLLIMPORT extern "C" __declspec( dllimport )
//---------------------------------------------------------------------------
DLLIMPORT bool __stdcall speInit(Tpx_RenderData &rd);
DLLIMPORT int __stdcall  speAddSurface(void);
DLLIMPORT bool __stdcall speSelectSurface(int sIndex);
DLLIMPORT bool __stdcall speDeleteSurface(int sIndex);
DLLIMPORT bool __stdcall speSetSurface(void *scanOrig, void *scanAlphaOrig, int width, int height, unsigned int scanlineAlignment);
DLLIMPORT bool __stdcall speSurfaceBegin(int width, int height);
DLLIMPORT bool __stdcall speSurfaceAddScanline(void *scanOrig, void *scanAlphaOrig);
DLLIMPORT bool __stdcall speSurfaceFinish(void);
DLLIMPORT bool __stdcall speSetShape(TspeShapeType shapeType);
DLLIMPORT bool __stdcall speSetBrush(TspeBrushType brushType);
DLLIMPORT bool __stdcall speSetStandardColors(unsigned int primColor, unsigned int secColor, unsigned int polyColor);
DLLIMPORT bool __stdcall speGetStandardColors(unsigned int &primColor, unsigned int &secColor, unsigned int &polyColor);
DLLIMPORT bool __stdcall speSetColorScheme(const int cScheme);
DLLIMPORT bool __stdcall speSetShadowColor(unsigned int sColor);
DLLIMPORT bool __stdcall speSetRender(TspeRenderType renderType);
DLLIMPORT bool __stdcall speSetRenderData(Tpx_RenderData &rd);
DLLIMPORT bool __stdcall speGetBrushCommon(Tpx_BrushCommonParams &par);
DLLIMPORT bool __stdcall speSetBrushCommon(Tpx_BrushCommonParams &par);
DLLIMPORT void* __stdcall speGetBrushSpecific(void);
DLLIMPORT bool __stdcall speSetBrushSpecific(void *bsp);
DLLIMPORT bool __stdcall speSetStamp(void *buffer, int width, int height, unsigned int scanlineAlignement);
DLLIMPORT bool __stdcall speSetTexture(void *buffer, int width, int height, unsigned int scanlineAlignement);
DLLIMPORT bool __stdcall speDeleteTexture(void);
DLLIMPORT bool __stdcall speSetBackgroundTile(void *buffer, int width, int height, unsigned int scanlineAlignement);
DLLIMPORT bool __stdcall speDeleteBackgroundTile(void);
DLLIMPORT bool __stdcall speSetPolyTexture(void *buffer, int width, int height, unsigned int scanlineAlignement);
DLLIMPORT bool __stdcall speDeletePolyTexture(void);
DLLIMPORT bool __stdcall speSelectBrush(int bIndex);
DLLIMPORT bool __stdcall speSetPalette3C(unsigned int c1, unsigned int c2, unsigned int c3);
DLLIMPORT bool __stdcall speSetPalette255C(unsigned int *pal);
DLLIMPORT bool __stdcall speUpdateSurface(void);
//
DLLIMPORT bool __stdcall speDrawRectangleRect(TRect *objRect, Tpx_Geometry &geometry);
DLLIMPORT bool __stdcall speDrawEllipseRect(TRect *objRect, Tpx_Geometry &geometry);
DLLIMPORT bool __stdcall speDrawRectangle(int x1, int y1, int x2, int y2, Tpx_Geometry &geometry);
DLLIMPORT bool __stdcall speDrawEllipse(int x1, int y1, int x2, int y2, Tpx_Geometry &geometry);
DLLIMPORT bool __stdcall speDrawPoly(TPoint *pts, int ptsCount, Tpx_Geometry &geometry);
//
DLLIMPORT bool __stdcall speGetMouseData(Tpx_MouseData &md);
DLLIMPORT bool __stdcall speHandMouseDown(TShiftState Shift, int X, int Y);
DLLIMPORT bool __stdcall speHandMouseMove(TShiftState Shift, int X, int Y);
DLLIMPORT bool __stdcall speHandMouseUp(TShiftState Shift, int X, int Y);
DLLIMPORT bool __stdcall speObjectMouseDown(TShiftState Shift, int X, int Y);
DLLIMPORT bool __stdcall speObjectMouseMove(TShiftState Shift, int X, int Y);
DLLIMPORT bool __stdcall speObjectMouseUp(TShiftState Shift, int X, int Y);
// 0.4
DLLIMPORT bool __stdcall speSetSizeEnvelope(wchar_t* str);      
DLLIMPORT bool __stdcall speSetCapacityEnvelope(wchar_t* str);  
DLLIMPORT bool __stdcall speSetScaleColors(unsigned int topVal, unsigned int botVal); 
// 0.5
DLLIMPORT bool __stdcall speSetCloneImage(void *buffer, int width, int height, unsigned int scanlineAlignement, bool shared);
DLLIMPORT bool __stdcall speSetClonePosition(int X, int Y);
// 0.6
DLLIMPORT bool __stdcall speDeleteCloneImage(void);
DLLIMPORT bool __stdcall speCloneSelf(TspeCloneType clType);
DLLIMPORT bool __stdcall speSetSelection(void *buffer, bool shared);
DLLIMPORT bool __stdcall speDeleteSelection(void);
DLLIMPORT bool __stdcall speSelectionClipping(bool clip);
DLLIMPORT wchar_t* __stdcall speGetVersion(void);
//
#endif
